@@ -26,6 +26,7 @@ from darker.git import (
     EditedLinenumsDiffer,
     RevisionRange,
     get_missing_at_revision,
+    get_rev1_path,
     git_get_content_at_revision,
     git_get_modified_python_files,
     git_is_repository,
@@ -127,7 +128,7 @@ def _reformat_single_file(  # pylint: disable=too-many-arguments,too-many-locals
 
     """
     src = root / relative_path
-    rev1_relative_path = _get_rev1_path(relative_path)
+    rev1_relative_path = get_rev1_path(relative_path)
     edited_linenums_differ = EditedLinenumsDiffer(root, revrange)
 
     # 4. run black
@@ -200,23 +201,6 @@ def _reformat_single_file(  # pylint: disable=too-many-arguments,too-many-locals
     return last_successful_reformat
 
 
-def _get_rev1_path(path: Path) -> Path:
-    """Return the relative path to the file in the old revision
-
-    This is usually the same as the relative path on the command line. But in the
-    special case of VSCode temporary files (like ``file.py.12345.tmp``), we actually
-    want to diff against the corresponding ``.py`` file instead.
-
-    """
-    if path.suffixes[-3::2] != [".py", ".tmp"]:
-        # The file name is not like `*.py.<HASH>.tmp`. Return it as such.
-        return path
-    # This is a VSCode temporary file. Drop the hash and the `.tmp` suffix to get the
-    # original file name for retrieving the previous revision to diff against.
-    path_with_hash = path.with_suffix("")
-    return path_with_hash.with_suffix("")
-
-
 def modify_file(path: Path, new_content: TextDocument) -> None:
     """Write new content to a file and inform the user by logging"""
     logger.info("Writing %s bytes into %s", len(new_content.string), path)
