@@ -3,8 +3,7 @@ import sys
 from pathlib import Path
 from typing import Any, Optional
 
-from black import find_project_root
-
+from darker.black_compat import find_project_root
 from darker.exceptions import IncompatiblePackageError, MissingPackageError
 from darker.utils import TextDocument
 
@@ -72,8 +71,15 @@ def apply_isort(
             ", ".join(f"{k}={v!r}" for k, v in isort_args.items())
         )
     )
+
+    code = content.string
+    try:
+        code = isort_code(code=code, **isort_args)
+    except isort.exceptions.FileSkipComment:
+        pass
+
     return TextDocument.from_str(
-        isort_code(code=content.string, **isort_args),
+        code,
         encoding=content.encoding,
         mtime=content.mtime,
     )
