@@ -6,7 +6,7 @@ from subprocess import check_call
 from typing import Dict, Optional
 
 import pytest
-from black import find_project_root
+from black import find_project_root as black_find_project_root
 
 from darker.git import _git_check_output_lines
 
@@ -19,9 +19,10 @@ class GitRepoFixture:
     @classmethod
     def create_repository(cls, root: Path) -> "GitRepoFixture":
         """Fixture method for creating a Git repository in the given directory"""
-        env = os.environ.copy()
-        # for testing, ignore ~/.gitconfig settings like templateDir and defaultBranch
-        env["HOME"] = str(root)
+        # For testing, ignore ~/.gitconfig settings like templateDir and defaultBranch.
+        # Also, this makes sure GIT_DIR or other GIT_* variables are not set, and that
+        # Git's messages are in English.
+        env = {"HOME": str(root), "LC_ALL": "C", "PATH": os.environ["PATH"]}
         instance = cls(root, env)
         # pylint: disable=protected-access
         instance._run("init")
@@ -87,10 +88,20 @@ def git_repo(tmp_path, monkeypatch):
     """Create a temporary Git repository and change current working directory into it"""
     repository = GitRepoFixture.create_repository(tmp_path)
     monkeypatch.chdir(tmp_path)
+    # While `GitRepoFixture.create_repository()` already deletes `GIT_*` environment
+    # variables for any Git commands run by the fixture, let's explicitly remove
+    # `GIT_DIR` in case a test should call Git directly:
+    monkeypatch.delenv("GIT_DIR", raising=False)
     return repository
 
 
 @pytest.fixture
 def find_project_root_cache_clear():
-    """Clear LRU caching in :func:`black.find_project_root` before each test"""
-    find_project_root.cache_clear()
+    """Clear LRU caching in :func:`black.find_project_root` before each test
+
+    NOTE: We use `darker.black_compat.find_project_root` to wrap Black's original
+    function since its signature has changed along the way. However, clearing the cache
+    needs to be done on the original of course.
+
+    """
+    black_find_project_root.cache_clear()
