@@ -3,6 +3,7 @@
 """Unit tests for :mod:`darker.linting`"""
 
 from pathlib import Path
+from textwrap import dedent
 from unittest.mock import call, patch
 
 import pytest
@@ -13,11 +14,17 @@ from darker.tests.helpers import raises_if_exception
 
 
 @pytest.mark.kwparametrize(
-    dict(line="module.py:42: Description", expect=(Path("module.py"), 42)),
-    dict(line="module.py:42:5: Description", expect=(Path("module.py"), 42)),
-    dict(line="no-linenum.py: Description", expect=(None, None)),
-    dict(line="mod.py:invalid-linenum:5: Description", expect=(None, None)),
-    dict(line="invalid linter output", expect=(None, None)),
+    dict(
+        line="module.py:42: Description\n",
+        expect=(Path("module.py"), 42, "module.py:42:", "Description"),
+    ),
+    dict(
+        line="module.py:42:5: Description\n",
+        expect=(Path("module.py"), 42, "module.py:42:5:", "Description"),
+    ),
+    dict(line="no-linenum.py: Description\n", expect=(Path(), 0, "", "")),
+    dict(line="mod.py:invalid-linenum:5: Description\n", expect=(Path(), 0, "", "")),
+    dict(line="invalid linter output\n", expect=(Path(), 0, "", "")),
 )
 def test_parse_linter_line(git_repo, monkeypatch, line, expect):
     """Linter output is parsed correctly"""
@@ -63,14 +70,14 @@ def test_check_linter_output():
         _descr="Check one file, report on a modified line in test.py",
         paths=["one.py"],
         location="test.py:1:",
-        expect_output=["test.py:1: {git_repo.root / 'one.py'}"],
+        expect_output=["", "test.py:1: {git_repo.root / 'one.py'}"],
         expect_log=[],
     ),
     dict(
         _descr="Check one file, report on a column of a modified line in test.py",
         paths=["one.py"],
         location="test.py:1:42:",
-        expect_output=["test.py:1:42: {git_repo.root / 'one.py'}"],
+        expect_output=["", "test.py:1:42: {git_repo.root / 'one.py'}"],
         expect_log=[],
     ),
     dict(
@@ -92,6 +99,7 @@ def test_check_linter_output():
         paths=["one.py", "two.py"],
         location="test.py:1:",
         expect_output=[
+            "",
             "test.py:1: {git_repo.root / 'one.py'} {git_repo.root / 'two.py'}"
         ],
         expect_log=[],
@@ -101,6 +109,7 @@ def test_check_linter_output():
         paths=["one.py", "two.py"],
         location="test.py:1:42:",
         expect_output=[
+            "",
             "test.py:1:42: {git_repo.root / 'one.py'} {git_repo.root / 'two.py'}"
         ],
         expect_log=[],
@@ -200,57 +209,37 @@ def test_run_linter_return_value(git_repo, location, expect):
     dict(
         linter_cmdlines=[],
         linters_return=[],
-        expect_result=False,
-    ),
-    dict(
-        linter_cmdlines=["linter"],
-        linters_return=[None],
-        expect_result=False,
+        expect_result=0,
     ),
     dict(
         linter_cmdlines=["linter"],
         linters_return=[0],
-        expect_result=False,
+        expect_result=0,
     ),
     dict(
         linter_cmdlines=["linter"],
         linters_return=[1],
-        expect_result=True,
+        expect_result=1,
     ),
     dict(
         linter_cmdlines=["linter"],
         linters_return=[42],
-        expect_result=True,
-    ),
-    dict(
-        linter_cmdlines=["linter1", "linter2"],
-        linters_return=[None, None],
-        expect_result=False,
-    ),
-    dict(
-        linter_cmdlines=["linter1", "linter2"],
-        linters_return=[None, 0],
-        expect_result=False,
-    ),
-    dict(
-        linter_cmdlines=["linter1", "linter2"],
-        linters_return=[None, 42],
-        expect_result=True,
+        expect_result=42,
     ),
     dict(
         linter_cmdlines=["linter1", "linter2"],
         linters_return=[0, 0],
-        expect_result=False,
+        expect_result=0,
     ),
     dict(
         linter_cmdlines=["linter1", "linter2"],
         linters_return=[0, 42],
-        expect_result=True,
+        expect_result=42,
     ),
     dict(
         linter_cmdlines=["linter1", "linter2 command line"],
         linters_return=[42, 42],
-        expect_result=True,
+        expect_result=84,
     ),
 )
 def test_run_linters(linter_cmdlines, linters_return, expect_result):
@@ -296,4 +285,39 @@ def test_run_linter_on_new_file(git_repo, capsys):
     )
 
     output = capsys.readouterr().out.splitlines()
-    assert output == [f"file2.py:1: {git_repo.root / 'file2.py'}"]
+    assert output == ["", f"file2.py:1: {git_repo.root / 'file2.py'}"]
+
+
+def test_run_linter_line_separation(git_repo, capsys):
+    """``run_linter`` separates contiguous blocks of linter output with empty lines"""
+    paths = git_repo.add({"a.py": "1\n2\n3\n4\n5\n6\n"}, commit="Initial commit")
+    paths["a.py"].write_bytes(b"a\nb\nc\nd\ne\nf\n")
+    linter_output = git_repo.root / "dummy-linter-output.txt"
+    linter_output.write_text(
+        dedent(
+            """
+            a.py:2: first block
+            a.py:3: of linter output
+            a.py:5: second block
+            a.py:6: of linter output
+            """
+        )
+    )
+
+    linting.run_linter(
+        f"cat {linter_output}",
+        Path(git_repo.root),
+        {Path(p) for p in paths},
+        RevisionRange("HEAD", ":WORKTREE:"),
+    )
+
+    result = capsys.readouterr().out
+    assert result == dedent(
+        """
+        a.py:2: first block
+        a.py:3: of linter output
+
+        a.py:5: second block
+        a.py:6: of linter output
+        """
+    )
